@@ -2,22 +2,33 @@
 
 use crate::app::error_handler;
 use crate::http::headers::ResponseHeader;
+use crate::http::mime::MimeType;
 use crate::http::{Request, Response, StatusCode};
 use crate::route::{try_find_path, LocatedPath};
 
 use std::fs::File;
 use std::io::Read;
+use std::path::PathBuf;
 use std::sync::Arc;
 
 const INDEX_FILES: [&str; 2] = ["index.html", "index.htm"];
 
 /// Serve the specified file, or a default error 404 if not found.
 pub fn serve_file<T>(file_path: &'static str) -> impl Fn(Request, Arc<T>) -> Response {
+    let path_buf = PathBuf::from(file_path);
+
     move |_, _| {
-        if let Ok(mut file) = File::open(file_path) {
+        if let Ok(mut file) = File::open(&path_buf) {
             let mut buf = Vec::new();
             if file.read_to_end(&mut buf).is_ok() {
-                return Response::new(StatusCode::OK, buf);
+                return if let Some(extension) = path_buf.extension() {
+                    Response::new(StatusCode::OK, buf).with_header(
+                        ResponseHeader::ContentType,
+                        MimeType::from_extension(extension.to_str().unwrap()).into(),
+                    )
+                } else {
+                    Response::new(StatusCode::OK, buf)
+                };
             }
         }
 
@@ -39,10 +50,19 @@ pub fn serve_as_file_path<T>(directory_path: &'static str) -> impl Fn(Request, A
         let file_path = request.uri.strip_prefix('/').unwrap_or(&request.uri);
         let path = format!("{}/{}", directory_path, file_path);
 
-        if let Ok(mut file) = File::open(path) {
+        let path_buf = PathBuf::from(path);
+
+        if let Ok(mut file) = File::open(&path_buf) {
             let mut buf = Vec::new();
             if file.read_to_end(&mut buf).is_ok() {
-                return Response::new(StatusCode::OK, buf);
+                return if let Some(extension) = path_buf.extension() {
+                    Response::new(StatusCode::OK, buf).with_header(
+                        ResponseHeader::ContentType,
+                        MimeType::from_extension(extension.to_str().unwrap()).into(),
+                    )
+                } else {
+                    Response::new(StatusCode::OK, buf)
+                };
             }
         }
 
@@ -70,10 +90,17 @@ pub fn serve_dir<T>(directory_path: &'static str) -> impl Fn(Request, Arc<T>, &s
                 LocatedPath::Directory => Response::empty(StatusCode::MovedPermanently)
                     .with_header(ResponseHeader::Location, format!("{}/", &request.uri)),
                 LocatedPath::File(path) => {
-                    if let Ok(mut file) = File::open(path) {
+                    if let Ok(mut file) = File::open(&path) {
                         let mut buf = Vec::new();
                         if file.read_to_end(&mut buf).is_ok() {
-                            return Response::new(StatusCode::OK, buf);
+                            return if let Some(extension) = path.extension() {
+                                Response::new(StatusCode::OK, buf).with_header(
+                                    ResponseHeader::ContentType,
+                                    MimeType::from_extension(extension.to_str().unwrap()).into(),
+                                )
+                            } else {
+                                Response::new(StatusCode::OK, buf)
+                            };
                         }
                     }
 
