@@ -1,10 +1,11 @@
 //! Provides a wrapper around the stream to allow for simpler APIs.
 
+#![allow(clippy::large_enum_variant)]
+
 #[cfg(feature = "tls")]
 use rustls::ServerConnection;
 
 use std::io::{Error, Read, Write};
-use std::marker::PhantomData;
 use std::net::{SocketAddr, TcpStream};
 use std::time::Duration;
 
@@ -12,34 +13,30 @@ use std::time::Duration;
 ///
 /// This is typically a wrapper around `TcpStream`, but is required to allow for a single API
 ///   to be used to process both regular and TLS connections.
-pub enum Stream<'a> {
+pub enum Stream {
     /// A regular TCP stream.
     Tcp(TcpStream),
     /// A TLS stream.
     #[cfg(feature = "tls")]
-    Tls(rustls::Stream<'a, ServerConnection, TcpStream>),
-    /// Phantom data to contain the lifetime of the stream when the TLS feature is disabled.
-    Phantom(PhantomData<&'a ()>),
+    Tls(rustls::StreamOwned<ServerConnection, TcpStream>),
 }
 
-impl<'a> Read for Stream<'a> {
+impl Read for Stream {
     fn read(&mut self, buf: &mut [u8]) -> std::io::Result<usize> {
         match self {
             Stream::Tcp(stream) => stream.read(buf),
             #[cfg(feature = "tls")]
             Stream::Tls(stream) => stream.read(buf),
-            Stream::Phantom(_) => panic!("Phantom data in stream enum"),
         }
     }
 }
 
-impl<'a> Write for Stream<'a> {
+impl Write for Stream {
     fn write(&mut self, buf: &[u8]) -> std::io::Result<usize> {
         match self {
             Stream::Tcp(stream) => stream.write(buf),
             #[cfg(feature = "tls")]
             Stream::Tls(stream) => stream.write(buf),
-            Stream::Phantom(_) => panic!("Phantom data in stream enum"),
         }
     }
 
@@ -48,19 +45,17 @@ impl<'a> Write for Stream<'a> {
             Stream::Tcp(stream) => stream.flush(),
             #[cfg(feature = "tls")]
             Stream::Tls(stream) => stream.flush(),
-            Stream::Phantom(_) => panic!("Phantom data in stream enum"),
         }
     }
 }
 
-impl<'a> Stream<'a> {
+impl Stream {
     /// Returns the socket address of the remote peer of this connection.
     pub fn peer_addr(&self) -> Result<SocketAddr, Error> {
         match self {
             Stream::Tcp(stream) => stream.peer_addr(),
             #[cfg(feature = "tls")]
             Stream::Tls(stream) => stream.sock.peer_addr(),
-            Stream::Phantom(_) => panic!("Phantom data in stream enum"),
         }
     }
 
@@ -70,7 +65,6 @@ impl<'a> Stream<'a> {
             Stream::Tcp(stream) => stream.shutdown(std::net::Shutdown::Both),
             #[cfg(feature = "tls")]
             Stream::Tls(stream) => stream.sock.shutdown(std::net::Shutdown::Both),
-            Stream::Phantom(_) => panic!("Phantom data in stream enum"),
         }
     }
 
@@ -86,7 +80,6 @@ impl<'a> Stream<'a> {
                 stream.sock.set_read_timeout(timeout)?;
                 stream.sock.set_write_timeout(timeout)
             }
-            Stream::Phantom(_) => panic!("Phantom data in stream enum"),
         }
     }
 
@@ -96,7 +89,6 @@ impl<'a> Stream<'a> {
             Stream::Tcp(stream) => stream.set_nonblocking(true),
             #[cfg(feature = "tls")]
             Stream::Tls(stream) => stream.sock.set_nonblocking(true),
-            Stream::Phantom(_) => panic!("Phantom data in stream enum"),
         }
     }
 
@@ -106,7 +98,6 @@ impl<'a> Stream<'a> {
             Stream::Tcp(stream) => stream.set_nonblocking(false),
             #[cfg(feature = "tls")]
             Stream::Tls(stream) => stream.sock.set_nonblocking(false),
-            Stream::Phantom(_) => panic!("Phantom data in stream enum"),
         }
     }
 }
